//----------------------------------------------------------------------
//	12f683 control register definitions
//----------------------------------------------------------------------

const	false = 0
const	true  = 1

pragma cpu_type 0x683

pragma physical_code_limit 0x800

hwreg cmp_xacc	  = 0x007C
hwreg aux_carry_0 = 0x007D
hwreg aux_carry_1 = 0x007E
hwreg W_ISR_SAV   = 0x007F


//  DO NOT explicitly map 0x70 - 0x7f to page 0
//  0x70 -  0x7f is mapped at
//  0xF0 -  0xFf
// 0x170 - 0x17f
// 0x1F0 - 0x1Ff

pragma define_ram_pages 0, 0x00, 0x6F
pragma define_ram_pages 1, 0x80, 0xEF

pragma define_ram_hole  0,  0
pragma define_ram_hole  2,  2
pragma define_ram_hole  3,  3
pragma define_ram_hole  4,  4
pragma define_ram_hole 10, 10
pragma define_ram_hole 11, 11

pragma define_variable_ram "group1", 0x20, 0x7B
pragma define_variable_ram "group2", 0xA0, 0xBF


hwreg INDF	= 0x0000
hwreg TMR0	= 0x0001
hwreg PCL	= 0x0002
hwreg STATUS	= 0x0003
hwreg FSR	= 0x0004
hwreg GPIO	= 0x0005

hwreg PCLATH	= 0x000A
hwreg INTCON	= 0x000B
hwreg PIR1	= 0x000C

hwreg TMR1L	= 0x000E
hwreg TMR1H	= 0x000F
hwreg T1CON	= 0x0010
hwreg TMR2	= 0x0011
hwreg T2CON	= 0x0012
hwreg CCPR1L	= 0x0013
hwreg CCPR1H	= 0x0014
hwreg CCP1CON 	= 0x0015

hwreg WDTCON	= 0x0018
hwreg CMCON0	= 0x0019
hwreg CMCON1	= 0x001A

hwreg ADRESH	= 0x001E
hwreg ADCON0	= 0x001F

hwreg OPTION_REG= 0x0081

hwreg TRISIO	= 0x0085

hwreg PIE1	= 0x008C

hwreg PCON	= 0x008E
hwreg OSCCON	= 0x008F
hwreg OSCTUNE 	= 0x0090

hwreg PR2	= 0x0092

hwreg WPU	= 0x0095
hwreg WPUA	= 0x0095
hwreg IOC	= 0x0096
hwreg IOCA	= 0x0096

hwreg VRCON	= 0x0099
hwreg EEDATA	= 0x009A
hwreg EEDAT	= 0x009A
hwreg EEADR	= 0x009B
hwreg EECON1	= 0x009C
hwreg EECON2	= 0x009D
hwreg ADRESL	= 0x009E
hwreg ANSEL	= 0x009F


//----------------------------------------------------------------------
//	bit definitions
//----------------------------------------------------------------------
include "hwreg-p12f683-sfr.h"
include "hwreg-p12f683-sfr-bit.h"
include "hwreg-p12f683-pkg.h"


//----------------------------------------------------------------------
//	12f683 configuration masks
//----------------------------------------------------------------------

pragma cpu_config_cnt 1

const CFG_FCMEN_ON		= 0x08003FFF
const CFG_FCMEN_OFF		= 0x080037FF
const CFG_IESO_ON		= 0x04003FFF
const CFG_IESO_OFF		= 0x04003BFF
const CFG_BOD_ON 		= 0x03003FFF
const CFG_BOD_NSLEEP		= 0x03003EFF
const CFG_BOD_SBODEN		= 0x03003DFF
const CFG_BOD_OFF		= 0x03003CFF
const CFG_CPD_ON 		= 0x00803F7F
const CFG_CPD_OFF		= 0x00803FFF
const CFG_CP_ON			= 0x00403FBF
const CFG_CP_OFF 		= 0x00403FFF
const CFG_MCLRE_ON		= 0x00203FFF
const CFG_MCLRE_OFF		= 0x00203FDF
const CFG_PWRTE_OFF		= 0x00103FFF
const CFG_PWRTE_ON		= 0x00103FEF
const CFG_WDT_ON 		= 0x00083FFF
const CFG_WDT_OFF		= 0x00083FF7

// NOTE: bits 13 and 12 (mask 0x30000000) are unimplemented
//	 in this PIC so a filler is used for this
//	 bit in the oscillator attribute

const CFG_LP_OSC 		= 0x30073FF8
const CFG_XT_OSC 		= 0x30073FF9
const CFG_HS_OSC 		= 0x30073FFA
const CFG_EC_OSC 		= 0x30073FFB
const CFG_INTRC_OSC_NOCLKOUT	= 0x30073FFC
const CFG_INTRC_OSC_CLKOUT	= 0x30073FFD
const CFG_INTOSC 		= 0x30073FFD
const CFG_INTOSCIO		= 0x30073FFC
const CFG_EXTRC_OSC_NOCLKOUT	= 0x30073FFE
const CFG_EXTRC_OSC_CLKOUT	= 0x30073FFF
const CFG_EXTRC			= 0x30073FFF
const CFG_EXTRCIO		= 0x30073FFE

// NOTE: the calibration word is at 0x2008
// this is where the second config mask normally
// lives

//----------------------------------------------------------------------
//----------------------------------------------------------------------

pragma build_config_option 1 BLD_OPT_PORTA_INIT

const BLD_OPT_PORTA_DIGITAL_IO = 0x01010001
const BLD_OPT_PORTA_ANALOG_IO  = 0x01010002


//----------------------------------------------------------------------
//----------------------------------------------------------------------
include "interrupt.h"

