//---------------------------------------------------------------------
//	16f627a control register definitions
//---------------------------------------------------------------------

const	false = 0
const	true  = 1

pragma cpu_type 0x627

pragma physical_code_limit 0x400

hwreg cmp_xacc	  = 0x007C
hwreg aux_carry_0 = 0x007D
hwreg aux_carry_1 = 0x007E
hwreg W_ISR_SAV   = 0x007F


//  DO NOT explicitly map 0x70 - 0x7f to page 0
//  0x70 -  0x7f is mapped at
//  0xF0 -  0xFf
// 0x170 - 0x17f
// 0x1F0 - 0x1Ff

pragma define_ram_pages 0, 0x00, 0x6F

pragma define_ram_pages 1, 0x80, 0xEF

pragma define_ram_pages 2, 0x100, 0x16F
pragma define_ram_pages 0, 0x101, 0x101
pragma define_ram_pages 0, 0x106, 0x106

pragma define_ram_pages 3, 0x180, 0x1EF
pragma define_ram_pages 1, 0x181, 0x181
pragma define_ram_pages 1, 0x186, 0x186

pragma define_ram_hole  0,  0
pragma define_ram_hole  2,  2
pragma define_ram_hole  3,  3
pragma define_ram_hole  4,  4
pragma define_ram_hole 10, 10
pragma define_ram_hole 11, 11

pragma define_variable_ram "group1", 0x20, 0x7B
pragma define_variable_ram "group2", 0xA0, 0xEF
pragma define_variable_ram "group3", 0x120, 0x14F


hwreg INDF	= 0x0000
hwreg TMR0	= 0x0001
hwreg PCL	= 0x0002
hwreg STATUS	= 0x0003
hwreg FSR	= 0x0004
hwreg PORTA	= 0x0005
hwreg PORTB	= 0x0006
hwreg PCLATH	= 0x000A
hwreg INTCON	= 0x000B
hwreg PIR1	= 0x000C
hwreg TMR1L	= 0x000E
hwreg TMR1H	= 0x000F
hwreg T1CON	= 0x0010
hwreg TMR2	= 0x0011
hwreg T2CON	= 0x0012
hwreg CCPR1L	= 0x0015
hwreg CCPR1H	= 0x0016
hwreg CCP1CON	= 0x0017
hwreg RCSTA	= 0x0018
hwreg TXREG	= 0x0019
hwreg RCREG	= 0x001A
hwreg CMCON	= 0x001F

hwreg OPTION_REG= 0x0081
hwreg TRISA	= 0x0085
hwreg TRISB	= 0x0086
hwreg PIE1	= 0x008C
hwreg PCON	= 0x008E
hwreg PR2	= 0x0092
hwreg TXSTA	= 0x0098
hwreg SPBRG	= 0x0099
hwreg EEDATA	= 0x009A
hwreg EEADR	= 0x009B
hwreg EECON1	= 0x009C
hwreg EECON2	= 0x009D
hwreg VRCON	= 0x009F


//----------------------------------------------------------------------
//	bit definitions
//----------------------------------------------------------------------
include "hwreg-p16f628-sfr.h"
include "hwreg-p16f628-sfr-bit.h"
include "hwreg-p16f628-pkg.h"


//----------------------------------------------------------------------
//	16f627a configuration masks
//----------------------------------------------------------------------

pragma cpu_config_cnt 1

const CFG_BOREN_ON                    = 0x00403FFF
const CFG_BOREN_OFF                   = 0x00403FBF
const CFG_CP_ON                       = 0x20001FFF
const CFG_CP_OFF                      = 0x20003FFF
const CFG_DATA_CP_ON                  = 0x01003EFF
const CFG_DATA_CP_OFF                 = 0x01003FFF
const CFG_BODEN_ON                    = 0x00403FFF	// Backwards compatability to 16F62X
const CFG_BODEN_OFF                   = 0x00403FBF	// Backwards compatability to 16F62X
const CFG_MCLRE_ON                    = 0x00203FFF
const CFG_MCLRE_OFF                   = 0x00203FDF

const CFG_PWRTE_OFF                   = 0x00083FFF
const CFG_PWRTE_ON                    = 0x00083FF7
const CFG_WDT_ON                      = 0x00043FFF
const CFG_WDT_OFF                     = 0x00043FFB
const CFG_LVP_ON                      = 0x00803FFF
const CFG_LVP_OFF                     = 0x00803F7F

// NOTE: bit 12..9 (mask 0x1E000000) are not implemented
//	 in this PIC so a filler is used for this
//	 bit in the oscillator attribute

const CFG_RC_OSC_CLKOUT               = 0x1E003FFF
const CFG_RC_OSC_NOCLKOUT             = 0x1E003FFE

const CFG_ER_OSC_CLKOUT               = 0x1E133FFF	// Backwards compatability to 16F62X
const CFG_ER_OSC_NOCLKOUT             = 0x1E133FFE	// Backwards compatability to 16F62X
const CFG_INTOSC_OSC_CLKOUT   	      = 0x1E133FFD
const CFG_INTOSC_OSC_NOCLKOUT         = 0x1E133FFC
const CFG_INTRC_OSC_CLKOUT   	      = 0x1E133FFD	// Backwards compatability to 16F62X
const CFG_INTRC_OSC_NOCLKOUT	      = 0x1E133FFC	// Backwards compatability to 16F62X
const CFG_EXTCLK_OSC                  = 0x1E133FEF
const CFG_HS_OSC                      = 0x1E133FEE
const CFG_XT_OSC                      = 0x1E133FED
const CFG_LP_OSC                      = 0x1E133FEC


//----------------------------------------------------------------------
//----------------------------------------------------------------------

pragma build_config_option 1 BLD_OPT_PORTA_INIT

const BLD_OPT_PORTA_DIGITAL_IO = 0x02010001
const BLD_OPT_PORTA_ANALOG_IO  = 0x02010002


//----------------------------------------------------------------------
//----------------------------------------------------------------------
include "interrupt.h"

