//----------------------------------------------------------------------
//	16f767 control register definitions
//----------------------------------------------------------------------

const	false = 0
const	true  = 1

pragma cpu_type 0x767

pragma physical_code_limit 0x2000

hwreg cmp_xacc	  = 0x007C
hwreg aux_carry_0 = 0x007D
hwreg aux_carry_1 = 0x007E
hwreg W_ISR_SAV   = 0x007F


//  DO NOT explicitly map 0x70 - 0x7f to page 0
//  0x70 -  0x7f is mapped at
//  0xF0 -  0xFf
// 0x170 - 0x17f
// 0x1F0 - 0x1Ff

pragma define_ram_pages 0, 0x00, 0x6F
pragma define_ram_pages 1, 0x80, 0xEF

pragma define_ram_pages 2, 0x100, 0x16F
pragma define_ram_pages 0, 0x101, 0x101
pragma define_ram_pages 0, 0x106, 0x106

pragma define_ram_pages 3, 0x180, 0x1EF
pragma define_ram_pages 1, 0x181, 0x181
pragma define_ram_pages 1, 0x186, 0x186

pragma define_ram_hole  0,  0
pragma define_ram_hole  2,  2
pragma define_ram_hole  3,  3
pragma define_ram_hole  4,  4
pragma define_ram_hole 10, 10
pragma define_ram_hole 11, 11

pragma define_variable_ram "group1", 0x20, 0x7B
pragma define_variable_ram "group2", 0xA0, 0xEF
pragma define_variable_ram "group3", 0x110, 0x16F
pragma define_variable_ram "group4", 0x190, 0x1EF


hwreg INDF	= 0x0000
hwreg TMR0	= 0x0001
hwreg PCL	= 0x0002
hwreg STATUS	= 0x0003
hwreg FSR	= 0x0004
hwreg PORTA	= 0x0005
hwreg PORTB	= 0x0006
hwreg PORTC	= 0x0007

hwreg PORTE	= 0x0009
hwreg PCLATH	= 0x000A
hwreg INTCON	= 0x000B
hwreg PIR1	= 0x000C
hwreg PIR2	= 0x000D
hwreg TMR1L	= 0x000E
hwreg TMR1H	= 0x000F
hwreg T1CON	= 0x0010
hwreg TMR2	= 0x0011
hwreg T2CON	= 0x0012
hwreg SSPBUF	= 0x0013
hwreg SSPCON	= 0x0014
hwreg CCPR1L	= 0x0015
hwreg CCPR1H	= 0x0016
hwreg CCP1CON 	= 0x0017
hwreg RCSTA	= 0x0018
hwreg TXREG	= 0x0019
hwreg RCREG	= 0x001A
hwreg CCPR2L	= 0x001B
hwreg CCPR2H	= 0x001C
hwreg CCP2CON 	= 0x001D
hwreg ADRESH	= 0x001E
hwreg ADCON0	= 0x001F

hwreg OPTION_REG= 0x0081
hwreg TRISA	= 0x0085
hwreg TRISB	= 0x0086
hwreg TRISC	= 0x0087

hwreg TRISE	= 0x0089
hwreg PIE1	= 0x008C
hwreg PIE2	= 0x008D
hwreg PCON	= 0x008E
hwreg OSCCON	= 0x008F
hwreg OSCTUNE 	= 0x0090
hwreg SSPCON2 	= 0x0091
hwreg PR2	= 0x0092
hwreg SSPADD	= 0x0093
hwreg SSPSTAT 	= 0x0094
hwreg CCPR3L	= 0x0095
hwreg CCPR3H	= 0x0096
hwreg CCP3CON 	= 0x0097
hwreg TXSTA	= 0x0098
hwreg SPBRG	= 0x0099
hwreg ADCON2	= 0x009B
hwreg CMCON	= 0x009C
hwreg CVRCON	= 0x009D
hwreg ADRESL	= 0x009E
hwreg ADCON1	= 0x009F

hwreg WDTCON	= 0x0105
hwreg LVDCON	= 0x0109
hwreg PMDATA	= 0x010C
hwreg PMADR	= 0x010D
hwreg PMDATH	= 0x010E
hwreg PMADRH	= 0x010F

hwreg PMCON1	= 0x018C


//----------------------------------------------------------------------
//	bit definitions
//----------------------------------------------------------------------
include "hwreg-p16f777-sfr.h"
include "hwreg-p16f777-sfr-bit.h"
include "hwreg-p16f767-pkg.h"


//----------------------------------------------------------------------
//	16f88 configuration masks
//----------------------------------------------------------------------

pragma cpu_config_cnt 2

// configuration word 0 attributes
const CFG_CP_ALL 	= 0x20001FFF
const CFG_CP_OFF 	= 0x20003FFF
const CFG_CCP2_RC1	= 0x10003FFF
const CFG_CCP2_RB3	= 0x10002FFF
const CFG_DEBUG_OFF	= 0x08003FFF
const CFG_DEBUG_ON	= 0x080037FF
const CFG_VBOR_2_0	= 0x01803FFF
const CFG_VBOR_2_7	= 0x01803F7F
const CFG_VBOR_4_2	= 0x01803EFF
const CFG_VBOR_4_5	= 0x01803E7F
const CFG_BOREN_1	= 0x00403FFF	// MUST BE CONFIGURED IN CONJUCTION W/ BORSEN (CONFIG2)
const CFG_BOREN_0	= 0x00403FBF	// MUST BE CONFIGURED IN CONJUCTION W/ BORSEN (CONFIG2)
const CFG_MCLR_ON	= 0x00203FFF
const CFG_MCLR_OFF	= 0x00203FDF
const CFG_PWRTE_OFF	= 0x00083FFF
const CFG_PWRTE_ON	= 0x00083FF7
const CFG_WDT_ON 	= 0x00043FFF
const CFG_WDT_OFF	= 0x00043FFB
const CFG_EXTRC_CLKOUT	= 0x06133FFF
const CFG_EXTRC_IO	= 0x06133FFE
const CFG_INTRC_CLKOUT	= 0x06133FFD
const CFG_INTRC_IO	= 0x06133FFC
const CFG_EXTCLK 	= 0x06133FEF
const CFG_HS_OSC 	= 0x06133FEE
const CFG_XT_OSC 	= 0x06133FED
const CFG_LP_OSC 	= 0x06133FEC

// configuration word 1 attributes

// NOTE: bits 13 to 7 and 5 to 2 (mask 0x3FBC0000) are unimplemented
//	 in this PIC so a filler is used for these
//	 bits in the BORSEN attribute

const CFG_BORSEN_1	= 0x7FFC3FFF	// MUST BE CONFIGURED IN CONJUCTION W/ BOREN (CONFIG1)
const CFG_BORSEN_0	= 0x7FFC3FBF	// MUST BE CONFIGURED IN CONJUCTION W/ BOREN (CONFIG1)
const CFG_IESO_ON	= 0x40023FFF
const CFG_IESO_OFF	= 0x40023FFD
const CFG_FCMEN_ON	= 0x40013FFF
const CFG_FCMEN_OFF	= 0x40013FFE


// **** Brown-out Reset configurations **** (Refer to the 16F7x7 Data Sheet for more details)
// BOREN_1 & BORSEN_1	=	BOR enabled and always on
// BOREN_1 & BORSEN_0	=	BOR enabled during operation and disabled during sleep by hardware
// BOREN_0 & BORSEN_1	=	BOR controlled by software bit SBOREN (PCON,2)
// BOREN_0 & BORSEN_0	=	BOR disabled

//----------------------------------------------------------------------
//----------------------------------------------------------------------

pragma build_config_option 1 BLD_OPT_PORTA_INIT

const BLD_OPT_PORTA_DIGITAL_IO = 0x05010001
const BLD_OPT_PORTA_ANALOG_IO  = 0x05010002


//----------------------------------------------------------------------
//----------------------------------------------------------------------
include "interrupt.h"

