//----------------------------------------------------------------------
//	16f819 control register definitions
//----------------------------------------------------------------------

const	false = 0
const	true  = 1

pragma cpu_type 0x819

pragma physical_code_limit 0x800

hwreg cmp_xacc	  = 0x007C
hwreg aux_carry_0 = 0x007D
hwreg aux_carry_1 = 0x007E
hwreg W_ISR_SAV   = 0x007F


//  DO NOT explicitly map 0x70 - 0x7f to page 0
//  0x70 -  0x7f is mapped at
//  0xF0 -  0xFf
// 0x170 - 0x17f
// 0x1F0 - 0x1Ff

pragma define_ram_pages 0, 0x00, 0x6F
pragma define_ram_pages 1, 0x80, 0xEF

pragma define_ram_pages 2, 0x100, 0x16F
pragma define_ram_pages 0, 0x101, 0x101
pragma define_ram_pages 0, 0x106, 0x106

pragma define_ram_pages 3, 0x180, 0x19F
pragma define_ram_pages 0, 0x1A0, 0x1FF
pragma define_ram_pages 1, 0x181, 0x181
pragma define_ram_pages 1, 0x186, 0x186

pragma define_ram_hole  0,  0
pragma define_ram_hole  2,  2
pragma define_ram_hole  3,  3
pragma define_ram_hole  4,  4
pragma define_ram_hole 10, 10
pragma define_ram_hole 11, 11

pragma define_variable_ram "group1", 0x20, 0x7B
pragma define_variable_ram "group2", 0xA0, 0xEF
pragma define_variable_ram "group3", 0x120, 0x16F


hwreg INDF	= 0x0000
hwreg TMR0	= 0x0001
hwreg PCL	= 0x0002
hwreg STATUS	= 0x0003
hwreg FSR	= 0x0004
hwreg PORTA	= 0x0005
hwreg PORTB	= 0x0006
hwreg PCLATH	= 0x000A
hwreg INTCON	= 0x000B
hwreg PIR1	= 0x000C
hwreg PIR2	= 0x000D
hwreg TMR1L	= 0x000E
hwreg TMR1H	= 0x000F
hwreg T1CON	= 0x0010
hwreg TMR2	= 0x0011
hwreg T2CON	= 0x0012
hwreg SSPBUF	= 0x0013
hwreg SSPCON	= 0x0014
hwreg CCPR1L	= 0x0015
hwreg CCPR1H	= 0x0016
hwreg CCP1CON 	= 0x0017
hwreg ADRESH	= 0x001E
hwreg ADCON0	= 0x001F

hwreg OPTION_REG= 0x0081
hwreg TRISA	= 0x0085
hwreg TRISB	= 0x0086
hwreg PIE1	= 0x008C
hwreg PIE2	= 0x008D
hwreg PCON	= 0x008E
hwreg OSCCON	= 0x008F
hwreg OSCTUNE 	= 0x0090
hwreg PR2	= 0x0092
hwreg SSPADD	= 0x0093
hwreg SSPSTAT 	= 0x0094
hwreg ADRESL	= 0x009E
hwreg ADCON1	= 0x009F

hwreg EEDATA	= 0x010C
hwreg EEADR	= 0x010D
hwreg EEDATH	= 0x010E
hwreg EEADRH	= 0x010F

hwreg EECON1	= 0x018C
hwreg EECON2	= 0x018D


//----------------------------------------------------------------------
//	bit definitions
//----------------------------------------------------------------------
include "hwreg-p16f818-sfr.h"
include "hwreg-p16f818-sfr-bit.h"
include "hwreg-p16f628-pkg.h"


//----------------------------------------------------------------------
//	16f819 configuration masks
//----------------------------------------------------------------------

pragma cpu_config_cnt 1

const CFG_CP_ALL		= 0x20001FFF
const CFG_CP_OFF		= 0x20003FFF
const CFG_CCP1_RB2		= 0x10003FFF
const CFG_CCP1_RB3		= 0x10002FFF
const CFG_DEBUG_OFF		= 0x08003FFF
const CFG_DEBUG_ON		= 0x080037FF
const CFG_WRT_ENABLE_OFF	= 0x06003FFF
const CFG_WRT_ENABLE_512	= 0x06003DFF
const CFG_WRT_ENABLE_1024 	= 0x06003BFF
const CFG_WRT_ENABLE_1536 	= 0x060039FF
const CFG_CPD_ON		= 0x01003EFF
const CFG_CPD_OFF 		= 0x01003FFF
const CFG_LVP_ON		= 0x00803FFF
const CFG_LVP_OFF 		= 0x00803F7F
const CFG_BODEN_ON		= 0x00403FFF
const CFG_BODEN_OFF		= 0x00403FBF
const CFG_MCLR_ON 		= 0x00203FFF
const CFG_MCLR_OFF		= 0x00203FDF
const CFG_PWRTE_OFF		= 0x00083FFF
const CFG_PWRTE_ON		= 0x00083FF7
const CFG_WDT_ON		= 0x00043FFF
const CFG_WDT_OFF 		= 0x00043FFB
const CFG_EXTRC_CLKOUT		= 0x00133FFF
const CFG_EXTRC_IO		= 0x00133FFE
const CFG_INTRC_CLKOUT		= 0x00133FFD
const CFG_INTRC_IO		= 0x00133FFC
const CFG_EXTCLK		= 0x00133FEF
const CFG_HS_OSC		= 0x00133FEE
const CFG_XT_OSC		= 0x00133FED
const CFG_LP_OSC		= 0x00133FEC

//----------------------------------------------------------------------
//----------------------------------------------------------------------

pragma build_config_option 1 BLD_OPT_PORTA_INIT

const BLD_OPT_PORTA_DIGITAL_IO = 0x05010001
const BLD_OPT_PORTA_ANALOG_IO  = 0x05010002


//----------------------------------------------------------------------
//----------------------------------------------------------------------
include "interrupt.h"

