//---------------------------------------------------------------------
//	16F874 control register definitions
//---------------------------------------------------------------------

const	false = 0
const	true  = 1

pragma cpu_type 0x874

pragma physical_code_limit 0x1000

hwreg cmp_xacc	  = 0x007C
hwreg aux_carry_0 = 0x007D
hwreg aux_carry_1 = 0x007E
hwreg W_ISR_SAV   = 0x007F

// NOTE:
// the 16f873 and 16f874 do not map 0x70 - 0x7f to
//  0xF0 -  0xFf
// 0x170 - 0x17f
// 0x1F0 - 0x1Ff

pragma define_ram_pages 0, 0x00, 0x7F

pragma define_ram_pages 1, 0x80, 0xFF

pragma define_ram_pages 2, 0x100, 0x11F
pragma define_ram_pages 0, 0x101, 0x101
pragma define_ram_pages 0, 0x106, 0x106
pragma define_ram_pages 0, 0x120, 0x17F

pragma define_ram_pages 3, 0x180, 0x19F
pragma define_ram_pages 1, 0x181, 0x181
pragma define_ram_pages 1, 0x186, 0x186
pragma define_ram_pages 1, 0x1A0, 0x1FF

pragma define_ram_hole  0,  0
pragma define_ram_hole  2,  2
pragma define_ram_hole  3,  3
pragma define_ram_hole  4,  4
pragma define_ram_hole 10, 10
pragma define_ram_hole 11, 11

pragma define_variable_ram "group1", 0x20, 0x7B
pragma define_variable_ram "group2", 0xA0, 0xFF


hwreg INDF	= 0x0000
hwreg TMR0	= 0x0001
hwreg PCL	= 0x0002
hwreg STATUS	= 0x0003
hwreg FSR	= 0x0004
hwreg PORTA	= 0x0005
hwreg PORTB	= 0x0006
hwreg PORTC	= 0x0007
hwreg PORTD	= 0x0008
hwreg PORTE	= 0x0009
hwreg PCLATH	= 0x000A
hwreg INTCON	= 0x000B
hwreg PIR1	= 0x000C
hwreg PIR2	= 0x000D
hwreg TMR1L	= 0x000E
hwreg TMR1H	= 0x000F
hwreg T1CON	= 0x0010
hwreg TMR2	= 0x0011
hwreg T2CON	= 0x0012
hwreg SSPBUF	= 0x0013
hwreg SSPCON	= 0x0014
hwreg CCPR1L	= 0x0015
hwreg CCPR1H	= 0x0016
hwreg CCP1CON	= 0x0017
hwreg RCSTA	= 0x0018
hwreg TXREG	= 0x0019
hwreg RCREG	= 0x001A
hwreg CCPR2L	= 0x001B
hwreg CCPR2H	= 0x001C
hwreg CCP2CON	= 0x001D
hwreg ADRESH	= 0x001E
hwreg ADCON0	= 0x001F

hwreg OPTION_REG= 0x0081
hwreg TRISA	= 0x0085
hwreg TRISB	= 0x0086
hwreg TRISC	= 0x0087
hwreg TRISD	= 0x0088
hwreg TRISE	= 0x0089
hwreg PIE1	= 0x008C
hwreg PIE2	= 0x008D
hwreg PCON	= 0x008E
hwreg SSPCON2	= 0x0091
hwreg PR2	= 0x0092
hwreg SSPADD	= 0x0093
hwreg SSPSTAT	= 0x0094
hwreg TXSTA	= 0x0098
hwreg SPBRG	= 0x0099
hwreg ADRESL	= 0x009E
hwreg ADCON1	= 0x009F

hwreg EEDATA	= 0x010C
hwreg EEADR	= 0x010D
hwreg EEDATH	= 0x010E
hwreg EEADRH	= 0x010F

hwreg EECON1	= 0x018C
hwreg EECON2	= 0x018D


//----------------------------------------------------------------------
//	bit definitions
//----------------------------------------------------------------------
include "hwreg-p16f877-sfr.h"
include "hwreg-p16f877-sfr-bit.h"
include "hwreg-p16f877-pkg.h"


//----------------------------------------------------------------------
//	16f874 configuration masks
//----------------------------------------------------------------------

pragma cpu_config_cnt 1

const CFG_CP_ALL                      = 0x30300FCF
const CFG_CP_HALF                     = 0x30301FDF
const CFG_CP_UPPER_256                = 0x30302FEF
const CFG_CP_OFF                      = 0x30303FFF
const CFG_WRT_ENABLE_ON               = 0x02003FFF
const CFG_WRT_ENABLE_OFF              = 0x02003DFF

const CFG_DEBUG_ON                    = 0x080037FF
const CFG_DEBUG_OFF                   = 0x08003FFF
const CFG_CPD_ON                      = 0x01003EFF
const CFG_CPD_OFF                     = 0x01003FFF
const CFG_LVP_ON                      = 0x00803FFF
const CFG_LVP_OFF                     = 0x00803F7F
const CFG_BODEN_ON                    = 0x00403FFF
const CFG_BODEN_OFF                   = 0x00403FBF
const CFG_PWRTE_OFF                   = 0x00083FFF
const CFG_PWRTE_ON                    = 0x00083FF7
const CFG_WDT_ON                      = 0x00043FFF
const CFG_WDT_OFF                     = 0x00043FFB

// NOTE: bit 10 (mask 0x04000000) is unimplemented
//	 in this PIC so a filler is used for this
//	 bit in the oscillator attribute

const CFG_RC_OSC                      = 0x04033FFF
const CFG_HS_OSC                      = 0x04033FFE
const CFG_XT_OSC                      = 0x04033FFD
const CFG_LP_OSC                      = 0x04033FFC


//----------------------------------------------------------------------
//----------------------------------------------------------------------

pragma build_config_option 1 BLD_OPT_PORTA_INIT

const BLD_OPT_PORTA_DIGITAL_IO = 0x07010001
const BLD_OPT_PORTA_ANALOG_IO  = 0x07010002


//----------------------------------------------------------------------
//----------------------------------------------------------------------
include "interrupt.h"

