//---------------------------------------------------------------------
//	16f876a control register definitions
//---------------------------------------------------------------------

const	false = 0
const	true  = 1

pragma cpu_type 0x876

pragma physical_code_limit 0x2000

hwreg cmp_xacc	  = 0x007C
hwreg aux_carry_0 = 0x007D
hwreg aux_carry_1 = 0x007E
hwreg W_ISR_SAV   = 0x007F


//  DO NOT explicitly map 0x70 - 0x7f to page 0
//  0x70 -  0x7f is mapped at
//  0xF0 -  0xFf
// 0x170 - 0x17f
// 0x1F0 - 0x1Ff

pragma define_ram_pages 0, 0x00, 0x6F
pragma define_ram_pages 1, 0x80, 0xEF

pragma define_ram_pages 2, 0x100, 0x16F
pragma define_ram_pages 0, 0x101, 0x101
pragma define_ram_pages 0, 0x106, 0x106

pragma define_ram_pages 3, 0x180, 0x1EF
pragma define_ram_pages 1, 0x181, 0x181
pragma define_ram_pages 1, 0x186, 0x186

pragma define_ram_hole  0,  0
pragma define_ram_hole  2,  2
pragma define_ram_hole  3,  3
pragma define_ram_hole  4,  4
pragma define_ram_hole 10, 10
pragma define_ram_hole 11, 11

pragma define_variable_ram "group1", 0x20, 0x7B
pragma define_variable_ram "group2", 0xA0, 0xEF
pragma define_variable_ram "group3", 0x110, 0x16F
pragma define_variable_ram "group4", 0x190, 0x1EF


hwreg INDF	= 0x0000
hwreg TMR0	= 0x0001
hwreg PCL	= 0x0002
hwreg STATUS	= 0x0003
hwreg FSR	= 0x0004
hwreg PORTA	= 0x0005
hwreg PORTB	= 0x0006
hwreg PORTC	= 0x0007

hwreg PCLATH	= 0x000A
hwreg INTCON	= 0x000B
hwreg PIR1	= 0x000C
hwreg PIR2	= 0x000D
hwreg TMR1L	= 0x000E
hwreg TMR1H	= 0x000F
hwreg T1CON	= 0x0010
hwreg TMR2	= 0x0011
hwreg T2CON	= 0x0012
hwreg SSPBUF	= 0x0013
hwreg SSPCON	= 0x0014
hwreg CCPR1L	= 0x0015
hwreg CCPR1H	= 0x0016
hwreg CCP1CON	= 0x0017
hwreg RCSTA	= 0x0018
hwreg TXREG	= 0x0019
hwreg RCREG	= 0x001A
hwreg CCPR2L	= 0x001B
hwreg CCPR2H	= 0x001C
hwreg CCP2CON	= 0x001D
hwreg ADRESH	= 0x001E
hwreg ADCON0	= 0x001F

hwreg OPTION_REG= 0x0081
hwreg TRISA	= 0x0085
hwreg TRISB	= 0x0086
hwreg TRISC	= 0x0087
hwreg PIE1	= 0x008C
hwreg PIE2	= 0x008D
hwreg PCON	= 0x008E
hwreg SSPCON2	= 0x0091
hwreg PR2	= 0x0092
hwreg SSPADD	= 0x0093
hwreg SSPSTAT	= 0x0094
hwreg TXSTA	= 0x0098
hwreg SPBRG	= 0x0099
hwreg CMCON	= 0x009C	// not present in non-A part
hwreg CVRCON	= 0x009D	// not present in non-A part
hwreg ADRESL	= 0x009E
hwreg ADCON1	= 0x009F

hwreg EEDATA	= 0x010C
hwreg EEADR	= 0x010D
hwreg EEDATH	= 0x010E
hwreg EEADRH	= 0x010F

hwreg EECON1	= 0x018C
hwreg EECON2	= 0x018D


//----------------------------------------------------------------------
//	bit definitions
//----------------------------------------------------------------------
include "hwreg-p16f876a-sfr.h"
include "hwreg-p16f876a-sfr-bit.h"
include "hwreg-p16f876-pkg.h"


//----------------------------------------------------------------------
//	16f876a configuration masks
//----------------------------------------------------------------------

pragma cpu_config_cnt 1

const CFG_CP_ALL                      = 0x20001FFF
const CFG_CP_OFF                      = 0x20003FFF
const CFG_WRT_OFF                     = 0x06003FFF	// No prog memmory write protection
const CFG_WRT_256                     = 0x06003DFF	// First 256 prog memmory write protected
const CFG_WRT_1FOURTH                 = 0x06003BFF	// First quarter prog memmory write protected
const CFG_WRT_HALF                    = 0x060039FF	// First half memmory write protected

const CFG_DEBUG_ON                    = 0x080037FF
const CFG_DEBUG_OFF                   = 0x08003FFF
const CFG_CPD_ON                      = 0x01003EFF
const CFG_CPD_OFF                     = 0x01003FFF
const CFG_LVP_ON                      = 0x00803FFF
const CFG_LVP_OFF                     = 0x00803F7F
const CFG_BODEN_ON                    = 0x00403FFF
const CFG_BODEN_OFF                   = 0x00403FBF
const CFG_PWRTE_OFF                   = 0x00083FFF
const CFG_PWRTE_ON                    = 0x00083FF7
const CFG_WDT_ON                      = 0x00043FFF
const CFG_WDT_OFF                     = 0x00043FFB

// NOTE: bit 12, 5 and 4 (mask 0x10300000) are not
//	 implemented in this PIC so a filler is used
//	 for this bit in the oscillator attribute

const CFG_RC_OSC                      = 0x10333FFF
const CFG_HS_OSC                      = 0x10333FFE
const CFG_XT_OSC                      = 0x10333FFD
const CFG_LP_OSC                      = 0x10333FFC


//----------------------------------------------------------------------
//----------------------------------------------------------------------

pragma build_config_option 1 BLD_OPT_PORTA_INIT

const BLD_OPT_PORTA_DIGITAL_IO = 0x06010001
const BLD_OPT_PORTA_ANALOG_IO  = 0x06010002


//----------------------------------------------------------------------
//----------------------------------------------------------------------
include "interrupt.h"

