//----------------------------------------------------------------------
//----------------------------------------------------------------------
// this program consists of 1 task + interrupt handler
//
// example of program that reads 2 switches and flashes 1 LED
//
// the switches are debounced in the background by the debounce driver
// which executs in the interrupt service roputine
//
// flashes LED between 1 and 8 times pauses then flashes again the
// number of times the LED flashes between pauses is selected by the
// user. By pressing one button the user increases the number of
// flashes. By pressing the other button the user decreases the number
// of flases


//----------------------------------------------------------------------
//----------------------------------------------------------------------

include "MCU-CONFIG/hwreg-p16f88.h"

pragma cpu_fosc 4000000

pragma cpu_config CFG_INTRC_IO
pragma cpu_config CFG_WDT_OFF
pragma cpu_config CFG_PWRTE_ON
pragma cpu_config CFG_MCLRE_OFF
pragma cpu_config CFG_BODEN_ON
pragma cpu_config CFG_LVP_OFF
pragma cpu_config CFG_CP_OFF
pragma cpu_config CFG_CPD_OFF

pragma cpu_config CFG_CCP1_RB0
pragma cpu_config CFG_WRT_PROTECT_NONE
pragma cpu_config CFG_DEBUG_OFF

pragma cpu_config CFG_IESO_OFF
pragma cpu_config CFG_FCMEN_OFF

pragma cpu_heartbeat 20

pragma build_config BLD_OPT_PORTA_DIGITAL_IO

include "LIB/fifo_lib.bas"

FIFO	switch_event_fifo[6]

include "LIB/debounce_lib.bas"


//----------------------------------------------------------------------
//----------------------------------------------------------------------
proc main()

	ulong	j

	ubyte	k, k2

	ubyte	flash_cnt

	// set outputs to known value before enabling output drivers
	PORTA = 0

	// set porta bit 0 to output, rest as inputs
	TRISA = 0xFE


	// set outputs to known value before enabling output drivers
	PORTB = 0

	// set all portb to inputs
	TRISB = 0xFF


	debounce_init(0xC0, 0x00)


	flash_cnt = 1

	while 1 do

		PORTA = 0

		for k=0 while k<(flash_cnt*2)-1 step k+=1 do

			for j=0 while j<10000 step j+=1 do
				k2 = 0
			done

			PORTA = PORTA ^ 1
		done

		for j=0 while j<40000 step j+=1 do
			k2 = 0
		done

		int	switch_change

		while 1 do

			switch_change = fifo_read_inline(&switch_event_fifo)

			if switch_change < 0 then
				break
			endif

			// a switch change has occured

			// NOTE: process all switch changes between each set
			// of flashes

			if (switch_change & 0x7f) == 6 then

				// porta bit 6 changed state

				if (switch_change & 0x80) == 0 then

					// NOTE: this switch reads 1 for open and 0 for closed
					// so look to 1 to 0 transition which means from
					// open to closed (not pressed to pressed)

					// adjust range from 1..8 to 0..7
					flash_cnt = flash_cnt - 1

					// decrease number of flashes
					flash_cnt = flash_cnt - 1

					// keep flashes in range 0..7
					flash_cnt = flash_cnt & 7

					// adjust range from 0..7 to 1..8
					flash_cnt = flash_cnt + 1
				endif

			else if (switch_change & 0x7f) == 7 then

				// porta bit 7 changed state

				if (switch_change & 0x80) == 0 then

					// NOTE: this switch reads 1 for open and 0 for closed
					// so look to 1 to 0 transition which means from
					// open to closed (not pressed to pressed)

					// adjust range from 1..8 to 0..7
					flash_cnt = flash_cnt - 1

					// increase number of flashes
					flash_cnt = flash_cnt + 1

					// keep flashes in range 0..7
					flash_cnt = flash_cnt & 7

					// adjust range from 0..7 to 1..8
					flash_cnt = flash_cnt + 1
				endif
			endif
		done
	done

endproc

proc intserv()

	debounce_queue_service()

endproc
