//----------------------------------------------------------------------
//----------------------------------------------------------------------
// Simple RS232 test program
//
// This program simply sends and receives characters to and from a
// terminal via the PIC hardware USART. The USART needs to be
// connected to the terminal via an RS232 buffer such as a MAX232
//
// The serial port settings are 8N1 and the Baud rate is 9600
//
// This program will accept input from the terminal and echo it back.
// When there is no input from the terminal, the last character received
// will be repeatedly sent back at 1 second intervals
//
// This program uses the USART polled interface (not the interrupt
// driven one)


//----------------------------------------------------------------------
//----------------------------------------------------------------------

include "MCU-CONFIG/hwreg-p16f628.h"

pragma cpu_fosc 4000000

pragma cpu_config CFG_INTRC_OSC_NOCLKOUT
pragma cpu_config CFG_WDT_OFF
pragma cpu_config CFG_PWRTE_ON
pragma cpu_config CFG_MCLRE_OFF
pragma cpu_config CFG_BODEN_ON
pragma cpu_config CFG_LVP_OFF
pragma cpu_config CFG_CP_OFF
pragma cpu_config CFG_DATA_CP_OFF

pragma cpu_heartbeat 20

pragma build_config BLD_OPT_PORTA_DIGITAL_IO

include "LIB/usart_lib.bas"

//----------------------------------------------------------------------
//----------------------------------------------------------------------
proc main()

	ubyte	j, k
	int	ch
	char	char_to_send


	TRISA = TRISA & ~1

	USART_init(BAUD_RATE_9600)

	char_to_send = 0'A'

	while 1 do

		PORTA = PORTA & ~1

		// wait 0.1 second
		delay_1ms 100

		PORTA = PORTA | 1

		USART_send_poll(char_to_send)

		for k=0 while k<3 step k+=1 do

			// wait 0.1 second
			delay_1ms 100
		done

		ch = USART_read_poll()

		if ch >= 0 then
			char_to_send = ch
		endif
	done

endproc


//----------------------------------------------------------------------
//----------------------------------------------------------------------
proc intserv()
endproc

