//----------------------------------------------------------------------
//----------------------------------------------------------------------
// RS232 to LCD test program
//
// This program is very similar to rs232-628-002.bas however in addition
// it also displays received characters on the attached LCD


//----------------------------------------------------------------------
//----------------------------------------------------------------------

include "MCU-CONFIG/hwreg-p16f628.h"

pragma cpu_fosc 4000000

pragma cpu_config CFG_INTRC_OSC_NOCLKOUT
pragma cpu_config CFG_WDT_OFF
pragma cpu_config CFG_PWRTE_ON
pragma cpu_config CFG_MCLRE_OFF
pragma cpu_config CFG_BODEN_ON
pragma cpu_config CFG_LVP_OFF
pragma cpu_config CFG_CP_OFF
pragma cpu_config CFG_DATA_CP_OFF

pragma cpu_heartbeat 20

pragma build_config BLD_OPT_PORTA_DIGITAL_IO

// include "LIB/strlib.bas"
include "LIB/lcd_lib.bas"

// 16 byte fifo (+3 bytes for fifo control)
FIFO	USART_input_fifo[16]
FIFO	USART_output_fifo[16]


// NOTE:
//	USART_input_fifo and USART_output_fifo
//		MUST BE DEFINED
//	before usart_int_lib.bas is included

include "LIB/usart_int_lib.bas"


//----------------------------------------------------------------------
//----------------------------------------------------------------------
proc main()

	ubyte	j, k
	int	ch
	char	char_to_send


	TRISA = TRISA & ~1

	USART_init(BAUD_RATE_9600)

	LCD_init()


	USART_enable_TX_interrupt()

	USART_enable_RX_interrupt()

	INTCON = INTCON | (1 << PEIE)

	char_to_send = 0'A'

	LCD_set_pos(0, 0)
	LCD_write_str("hello world")
	LCD_set_pos(0, 1)

	USART_send_str("hello world")

	while 1 do

		PORTA = PORTA & ~1

		// wait 0.1 second
		delay_1ms 100

		PORTA = PORTA | 1

		USART_send(char_to_send)

		for k=0 while k<3 step k+=1 do

			// wait 0.1 second
			delay_1ms 100
		done

		ch = USART_read()

		if ch >= 0 then
			char_to_send = ch

			if ch == 10  ||  ch == 13 then
				LCD_set_pos(0, 0)
			else
				LCD_write_char(ch)
			endif
		endif
	done

endproc


//----------------------------------------------------------------------
//----------------------------------------------------------------------
proc intserv()

	USART_service_RX()

	USART_service_TX()

endproc

