//----------------------------------------------------------------------
//----------------------------------------------------------------------

include "MCU-CONFIG/hwreg-p16f876.h"

pragma cpu_fosc 4000000

pragma cpu_config CFG_CP_OFF
pragma cpu_config CFG_WRT_ENABLE_ON
pragma cpu_config CFG_DEBUG_OFF
pragma cpu_config CFG_CPD_OFF
pragma cpu_config CFG_LVP_OFF
pragma cpu_config CFG_BODEN_OFF
pragma cpu_config CFG_PWRTE_ON
pragma cpu_config CFG_WDT_OFF
pragma cpu_config CFG_XT_OSC

pragma cpu_heartbeat 20

pragma build_config BLD_OPT_PORTA_DIGITAL_IO

// include "LIB/strlib.bas"
include "LIB/lcd_lib.bas"

include "LIB/fifo_lib.bas"

FIFO	switch_event_fifo[6]

include "LIB/keypad_lib.bas"



// NOTE: the use of the user defined character 7
// this is because the LCD uses the yen symbol in
// place of where the ASCII backslash would normally
// be

const char spin = "|/-", 7

//	*....
//	.*...
//	.*...
//	..*..
//	...*.
//	...*.
//	....*
//	.....

const ubyte backslash_glyph = 0x10, 0x08, 0x08, 0x04, 0x02, 0x02, 0x01, 0x00


//----------------------------------------------------------------------
//----------------------------------------------------------------------
proc task_1()

	keypad_init()

	while 1 do

		debounce_keypad_queue_service()

		task_wait 1
	done

endproc


//----------------------------------------------------------------------
//----------------------------------------------------------------------
proc main()

	int	loop_cnt
	ubyte	acc

	ubyte	pos


	task_start &task_1

	LCD_init()

	LCD_define_glyph(7, &backslash_glyph)

	LCD_cursor_off()

	loop_cnt = 0

	pos = 0

	while 1 do

		// wait for a switch event
		task_wait 5 while_empty switch_event_fifo

		int	ch

		ch = fifo_read_inline(&switch_event_fifo)

		if ch >= 0  &&  (ch & 0x80) == 0 then

			// only update display on key press
			// not key release

 			LCD_set_pos(0, 0)


			select ch & 0x7f of

			case 0'0'
				LCD_write_str("zero ")
				break


			case 0'1'
				LCD_write_str("one  ")
				break


			case 0'2'
				LCD_write_str("two  ")
				break


			case 0'3'
				LCD_write_str("three")
				break


			case 0'4'
				LCD_write_str("four ")
				break


			case 0'5'
				LCD_write_str("five ")
				break


			case 0'6'
				LCD_write_str("six  ")
				break


			case 0'7'
				LCD_write_str("seven")
				break


			case 0'8'
				LCD_write_str("eight")
				break


			case 0'9'
				LCD_write_str("nine ")
				break

			default
				LCD_write_char(ch & 0x7f)

			end_select

			pos = (pos + 1) & 15
		endif

		LCD_set_pos(0, 1)

		acc = (loop_cnt >> 2) & 0x03
		LCD_write_char(spin[acc])

		loop_cnt += 1
	done

endproc


//----------------------------------------------------------------------
//----------------------------------------------------------------------
proc intserv()
endproc
