//----------------------------------------------------------------------
//----------------------------------------------------------------------
// simple LCD test program
//
// This program writes an incrementing number to the attached LCD and
// shows three spinning progress gages. This program also demonstates
// the ease with which XCSB can manipulated and display 32 bit numbers.


//----------------------------------------------------------------------
//----------------------------------------------------------------------

include "MCU-CONFIG/hwreg-p16f876.h"

pragma cpu_fosc 4000000

pragma cpu_config CFG_CP_OFF
pragma cpu_config CFG_WRT_ENABLE_ON
pragma cpu_config CFG_DEBUG_OFF
pragma cpu_config CFG_CPD_OFF
pragma cpu_config CFG_LVP_OFF
pragma cpu_config CFG_BODEN_OFF
pragma cpu_config CFG_PWRTE_ON
pragma cpu_config CFG_WDT_OFF
pragma cpu_config CFG_XT_OSC

pragma cpu_heartbeat 20

pragma build_config BLD_OPT_PORTA_DIGITAL_IO

include "LIB/str_byte_lib.bas"
include "LIB/str_int_lib.bas"
include "LIB/str_long_lib.bas"
include "LIB/lcd_lib.bas"


// NOTE: the use of the user defined character 7
// this is because the LCD uses the yen symbol in
// place of where the ASCII backslash would normally
// be

const char spin = "|/-", 7

//	*....
//	.*...
//	.*...
//	..*..
//	...*.
//	...*.
//	....*
//	.....

const ubyte backslash_glyph = 0x10, 0x08, 0x08, 0x04, 0x02, 0x02, 0x01, 0x00

//----------------------------------------------------------------------
//----------------------------------------------------------------------
proc main()

	char	buff[10]

	ulong	val

	ubyte	acc


	LCD_init()

	val = 0

	LCD_define_glyph(7, &backslash_glyph)

	LCD_cursor_off()

	while 1 do

		long_to_str(&buff, val)

		LCD_set_pos(0, 0)

		LCD_write_str(&buff)


		LCD_set_pos(0, 1)

		acc = (val >> 7) & 0x03
		LCD_write_char(spin[acc])

		acc = (val >> 6) & 0x03
		LCD_write_char(spin[acc])

		acc = (val >> 5) & 0x03
		LCD_write_char(spin[acc])

		val += 1
	done

endproc


//----------------------------------------------------------------------
//----------------------------------------------------------------------
proc intserv()
endproc
