; CPU_HEARTBEAT	is defined by "pragma cpu_heartbeat" statement.
;	A good default is 20 beats per second
;	50 interrupts per second (is 20mS interval)

; CPU_FOSC is defined by "pragma cpu_fosc" statement.
;	A value of 4000000 means 4MHz clock

; 17 is number of cycles between start of
;    interrupt and timer reload, 2 is timer
;    load sync delay
; BEWARE: there is an interrupt latency of 3 cycles
TMR0_reload_adjust	.equ	17 + 3 + 2

; TMR0 prescaler
; bits 0-2 are used for prescaler value (2^(n+1))

TMR0_prescale_val	.set	BIT_CNT( ((CPU_FOSC / 4) - TMR0_reload_adjust) / CPU_HEARTBEAT )
TMR0_prescale_val	.set	TMR0_prescale_val - 8

.if TMR0_prescale_val < 0
TMR0_prescale_val	.set	0
.endif

.if TMR0_prescale_val > 7
TMR0_prescale_val	.set	7
.endif

TMR0_reset_val		.set	((CPU_FOSC / 4) - TMR0_reload_adjust) / (1 << (TMR0_prescale_val+1)) / CPU_HEARTBEAT

TMR0_reset_val		.set	INT(TMR0_reset_val)

TMR0_reset_adjust	.set	((CPU_FOSC / 4) - TMR0_reload_adjust) - (TMR0_reset_val * (1 << (TMR0_prescale_val+1)) * CPU_HEARTBEAT)

TMR0_reset_adjust	.set	TMR0_reset_adjust * 256 / (1 << (TMR0_prescale_val+1)) / CPU_HEARTBEAT

; there are other factors which make the timer inaccurate,
; trying to improve accuracy by improving the resolution
; of the adjustment is pointless

TMR0_reset_adjust	.set	INT(TMR0_reset_adjust) & 0xff

INTSERV_STATUS_TIMER_INTERRUPT	.equ	0

;======================
startup		.macro

		bcf	INTCON,GIE		; disable global interrupts

;----------------------

; init output latchs of all port

		clrf	PORTA
		clrf	PORTB

; define input and output ports by writing 1 for input and 0 for
; output to corresponding bit of data direction register (called the
; tris register)

		movlw	0xff			; set all port to inputs
		movwf	TRISA
		movwf	TRISB

		.if BLD_OPT_PORTA_INIT == 1

			.if (CPU_TYPE & 0xff0) == 0x620

				; 16f627, 16f628, 16f648

				movlw	7
				movwf	CMCON

			.else
				.if (CPU_TYPE & 0xff0) == 0x870

					; 16f876, 16f877

					movlw	6
					movwf	ADCON1

				.endif
			.endif
		.endif

		init_global_fifos

; init the interrupt control variable used by
; interrupt_enable and interrupt_disable functions
		clrf	interrupt_enable_cnt

; bits 0-2 are used for prescaler value (2^(n+1))
; setup TMR0 as internal timmer with prescaler
		movlw	0x80 | TMR0_prescale_val

		movwf	OPTION_REG

		movlw	TMR0_reset_val
		movwf	timer_reset_val
		clrf	timer_reset_adjust

		movwf	TMR0

; enable global interrupts, TMR0 interrupts
		movlw	(1 << GIE) | (1 << T0IE)
		movwf	INTCON

		clrf	current_task_number

		movlw	0xff

MAC_J_VAR	.set	0

		.while MAC_J_VAR < max_task_number

		clrf	task_run_list + (MAC_J_VAR * 2) + 0
		clrf	task_run_list + (MAC_J_VAR * 2) + 1

		movwf	task_timers + (MAC_J_VAR * 2) + 0
		movwf	task_timers + (MAC_J_VAR * 2) + 1

MAC_J_VAR	.set	MAC_J_VAR + 1

		.done

;----------------------

		; dispatch user defined main function
		goto	main

		.endm


;======================
declare_intserv_RAM	.macro	task_cnt

STATUS_ISR_SAV		.ds	1
PCLATH_ISR_SAV		.ds	1
FSR_ISR_SAV		.ds	1
cmp_xacc_ISR_SAV	.ds	1
aux_carry_0_ISR_SAV	.ds	1
aux_carry_1_ISR_SAV	.ds	1

timer_reset_val		.ds	1
timer_reset_adjust	.ds	1

intserv_status		.ds	1
heatbeat_cnt		.ds	2

current_task_number	.ds	1
task_acc		.dsw	1
task_run_list		.dsw	task_cnt
task_timers		.dsw	task_cnt

		.endm


;======================
intserv_prolog	.macro	task_cnt

		.func_scope_begin	"intserv_prolog"="intserv_prolog", 0

		movwf	W_ISR_SAV		; W_ISR_SAV is accessable from any bank
	
		swapf	STATUS,w

		movwf	STATUS_ISR_SAV
		swapf	STATUS_ISR_SAV
	
		movf	PCLATH,w
		movwf	PCLATH_ISR_SAV
	
		movf	FSR,w
		movwf	FSR_ISR_SAV

;----------------------
; heatbeat
	
		clrf	intserv_status

		btfss	INTCON,T0IF		; process TMR0 overflow only if it
		goto	isr_lab_01		;    has actually occured

		movf	timer_reset_val,w
		movwf	TMR0
	

		movlw	TMR0_reset_val
		movwf	timer_reset_val

		movlw	TMR0_reset_adjust
		addwf	timer_reset_adjust

		btfsc	STATUS,C
		incf	timer_reset_val		; factional timer adjust (integer component
						;    of sum of factions)

		comf	timer_reset_val		; TMR0 increments NOT decrements and timer
		incf	timer_reset_val		;    interrupt is on 0xff to 0x00 overflow
						;    so form 2's complement of time period




		bsf	intserv_status, INTSERV_STATUS_TIMER_INTERRUPT

		incf	heatbeat_cnt+0
		btfsc	STATUS,Z
		incf	heatbeat_cnt+1

		bcf	INTCON,T0IF		; reset TMR0 interrupt source

;----------------------

		dec_task_timers_declare	task_cnt

isr_lab_01

		movf	cmp_xacc,w
		movwf	cmp_xacc_ISR_SAV

		movf	aux_carry_0,w
		movwf	aux_carry_0_ISR_SAV

		movf	aux_carry_1,w
		movwf	aux_carry_1_ISR_SAV

;----------------------

		; dispatch user defined interrupt handler
		goto	intserv

		.func_scope_end		0

		.endm


;======================
intserv_epilog	.macro

		movf	aux_carry_1_ISR_SAV,w
		movwf	aux_carry_1

		movf	aux_carry_0_ISR_SAV,w
		movwf	aux_carry_0

		movf	cmp_xacc_ISR_SAV,w
		movwf	cmp_xacc

		movf	FSR_ISR_SAV,w
		movwf	FSR
	
		movf	PCLATH_ISR_SAV,w
		movwf	PCLATH
	
		movf	STATUS_ISR_SAV,w
		movwf	STATUS
	
		swapf	W_ISR_SAV
		swapf	W_ISR_SAV,w
	
		retfie

		.endm

;======================
fp_unpack	.macro	fp_accX, fp_expX, fp_signX

xxufp_09	.set	LABEL("xxufp_09_"+MACINV)

		movf	fp_accX+3,w
		movwf	fp_expX
		rlf	fp_accX+2,w
		rlf	fp_expX

		clrf	fp_signX
		rlf	fp_signX

		clrf	fp_accX+3

		movf	fp_accX+0,w
		iorwf	fp_accX+1,w
		iorwf	fp_accX+2,w
		iorwf	fp_expX,w

		btfsc	STATUS,Z
		goto	xxufp_09

		bsf	fp_accX+2,7

xxufp_09

		.endm

;======================
fp_pack		.macro	fp_accX, fp_expX, fp_signX

		rrf	fp_signX,w
		rrf	fp_expX,w
		movwf	fp_accX+3

		bcf	fp_accX+2,7
		btfsc	fp_expX,0
		bsf	fp_accX+2,7

		.endm

